==> haskell-listlike-4.6-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-listlike.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ListLike
version: 4.6
id: ListLike-4.6-JEzTaaquo5dC55mXhhHzIE
key: ListLike-4.6-JEzTaaquo5dC55mXhhHzIE
license: BSD3
copyright: Copyright (c) 2007-2008 John Goerzen
maintainer: John Lato <jwlato@gmail.com>
stability: Stable
homepage: http://github.com/JohnLato/listlike
synopsis: Generic support for list-like structures
description:
    Generic support for list-like structures in Haskell.
    .
    The ListLike module provides a common interface to the various Haskell
    types that are list-like.  Predefined interfaces include standard
    Haskell lists, Arrays, ByteStrings, and lazy ByteStrings.  Custom
    types can easily be made ListLike instances as well.
    .
    ListLike also provides for String-like types, such as String and
    ByteString, for types that support input and output, and for types that can handle
    infinite lists.
category: Generics
author: John Goerzen
exposed: True
indefinite: False
exposed-modules:
    Data.ListLike Data.ListLike.Base Data.ListLike.CharString
    Data.ListLike.Chars Data.ListLike.DList Data.ListLike.FMList
    Data.ListLike.FoldableLL Data.ListLike.IO Data.ListLike.Instances
    Data.ListLike.String Data.ListLike.Text Data.ListLike.Text.Builder
    Data.ListLike.Text.Text Data.ListLike.Text.TextLazy
    Data.ListLike.UTF8 Data.ListLike.Utils Data.ListLike.Vector
    Data.ListLike.Vector.Generic Data.ListLike.Vector.Storable
    Data.ListLike.Vector.Unboxed Data.ListLike.Vector.Vector
abi: 0c90dfa857ce6d107c1203186ebae6a8
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/ListLike-4.6
library-dirs: /usr/lib/ghc-8.2.2/site-local/ListLike-4.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/ListLike-4.6
hs-libraries: HSListLike-4.6-JEzTaaquo5dC55mXhhHzIE
depends:
    base-4.10.1.0 containers-0.5.10.2 bytestring-0.10.8.2 array-0.5.2.0
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc
    fmlist-0.9.2-5s08raTrKC6Ifm5la47EVy
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO deepseq-1.4.3.0
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
             dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc=891025a77d043cfd28f763ce7f5a4b16
             fmlist-0.9.2-5s08raTrKC6Ifm5la47EVy=2c4909e76d45fdd131438bc36617a8d9
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
haddock-interfaces: /usr/share/doc/haskell-listlike/html/ListLike.haddock
haddock-html: /usr/share/doc/haskell-listlike/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-listlike-4.6-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-listlike.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ListLike
version: 4.6
id: ListLike-4.6-L4OH4ExY4o8ACklospouj7
key: ListLike-4.6-L4OH4ExY4o8ACklospouj7
license: BSD3
copyright: Copyright (c) 2007-2008 John Goerzen
maintainer: John Lato <jwlato@gmail.com>
stability: Stable
homepage: http://github.com/JohnLato/listlike
synopsis: Generic support for list-like structures
description:
    Generic support for list-like structures in Haskell.
    .
    The ListLike module provides a common interface to the various Haskell
    types that are list-like.  Predefined interfaces include standard
    Haskell lists, Arrays, ByteStrings, and lazy ByteStrings.  Custom
    types can easily be made ListLike instances as well.
    .
    ListLike also provides for String-like types, such as String and
    ByteString, for types that support input and output, and for types that can handle
    infinite lists.
category: Generics
author: John Goerzen
exposed: True
indefinite: False
exposed-modules:
    Data.ListLike Data.ListLike.Base Data.ListLike.CharString
    Data.ListLike.Chars Data.ListLike.DList Data.ListLike.FMList
    Data.ListLike.FoldableLL Data.ListLike.IO Data.ListLike.Instances
    Data.ListLike.String Data.ListLike.Text Data.ListLike.Text.Builder
    Data.ListLike.Text.Text Data.ListLike.Text.TextLazy
    Data.ListLike.UTF8 Data.ListLike.Utils Data.ListLike.Vector
    Data.ListLike.Vector.Generic Data.ListLike.Vector.Storable
    Data.ListLike.Vector.Unboxed Data.ListLike.Vector.Vector
abi: e5f4fd926a4762bd827b6ed554c580eb
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/ListLike-4.6
library-dirs: /usr/lib/ghc-8.2.2/site-local/ListLike-4.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/ListLike-4.6
hs-libraries: HSListLike-4.6-L4OH4ExY4o8ACklospouj7
depends:
    base-4.10.1.0 containers-0.5.10.2 bytestring-0.10.8.2 array-0.5.2.0
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc
    fmlist-0.9.2-5s08raTrKC6Ifm5la47EVy
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO deepseq-1.4.3.0
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
             dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc=891025a77d043cfd28f763ce7f5a4b16
             fmlist-0.9.2-5s08raTrKC6Ifm5la47EVy=2c4909e76d45fdd131438bc36617a8d9
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
haddock-interfaces: /usr/share/doc/haskell-listlike/html/ListLike.haddock
haddock-html: /usr/share/doc/haskell-listlike/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
